package pps.core.task.job;

import cn.hutool.core.util.ObjectUtil;
import pps.cloud.base.service.IConfigOilFieldCloudService;
import pps.cloud.base.service.data.config_oil_field.GetConfigOilFieldOutput;
import pps.core.common.cache.TaskLockCache;
import pps.core.common.constant.BusinessConstant;
import xstartup.base.XContext;
import xstartup.data.XSingleResult;

/**
 * 任务公用服务
 *
 * @author ZWT
 * @date 2024/06/25 15:26
 */
public class JobCommonService {

    /**
     * 获取当前配置
     *
     * @param context 上下文
     * @return {@link GetConfigOilFieldOutput }
     */
    public GetConfigOilFieldOutput getCurrentConfig(XContext context) {
        IConfigOilFieldCloudService bean = context.getBean(IConfigOilFieldCloudService.class);
        XSingleResult<GetConfigOilFieldOutput> currentConfig = bean.getCurrentConfig(context);
        currentConfig.throwIfFail();
        return currentConfig.getResult();
    }

    /**
     * 已关闭
     *
     * @param config 配置
     * @return boolean
     */
    public boolean isClosed(GetConfigOilFieldOutput config) {
        return ObjectUtil.hasNull(config, config.getApiTaskIsEnable()) || config.getApiTaskIsEnable().equals(BusinessConstant.ONE);
    }

    /**
     * 设置缓存
     *
     * @param xContext x上下文
     * @param key      钥匙
     */
    public void setCache(XContext xContext, String key) {
        TaskLockCache cache = new TaskLockCache();
        cache.setRedisKey(key);
        cache.setRedisValue(key);
        TaskLockCache.set(xContext, cache);
    }
}